<?php

namespace Themes\eyerecord\pro\app\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use Illuminate\Support\Facades\Cookie;
use Illuminate\Support\Facades\Validator;

class LoginController extends Controller
{
    private $callApiService;

    public function __construct(CallApiService $callApiService)
    {
        $this->callApiService = $callApiService;
    }

    public function index()
    {
        [$oauth2InfoList, $develLoginInfo] = setupSsoClientOrLoginInfo();

        return view('views.auth.member-login', compact('oauth2InfoList', 'develLoginInfo'));
    }

    public function local()
    {
        [$oauth2InfoList, $develLoginInfo] = setupSsoClientOrLoginInfo();

        return view('views.auth.member-local-login', compact('oauth2InfoList', 'develLoginInfo'));
    }

    public function store()
    {
        $validator = validator::make(request()->all(), [
            'email' => ['required', 'email'],
            'password' => ['required'],
        ]);

        if ($validator->fails()) {
            return redirect()->back()
                ->withErrors($validator)
                ->withInput();
        }

        $data = [
            'Email' => request('email'),
            'Password' => request('password')
        ];
        $response = $this->callApiService->callApi([
            'url' => 'member-login',
            'data' => $data
        ]);

//        dd($response);

        if (isset($response['apiStatus'])) {
            if ($response['apiStatus'] === 701) {
                return redirect()->route('member-verify-resend', ['email' => request('email')]);
            } else {
                $mgs = $response['body'] ?? _e('API request failed. Please Check');
                notify()->error($mgs, 'Error', 'bottomRight');
                return redirect()->back()->withInput();
            }
        }

        session()->put('locale', \Str::of($response['CountryCode'])->explode('_')->first());
        session()->put('member', array_merge($response, ['is_member' => true, 'Ip' => request()->ip()]));
        session()->forget('user');

        $redirectUrl = getLoginRedirectUrl(request('previous_url'));

        if (request('remember')) {
            $minutes = time() + 60 * 60 * 24 * 100;
            return redirect()->to($redirectUrl)->withCookie(cookie('dabory_member_info', serialize($data), $minutes));
        }

        return redirect()->to($redirectUrl)->withCookie(Cookie::forget('dabory_member_info'));
    }
}
