<?php

namespace Themes\eyerecord\pro\app\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use Illuminate\Support\Facades\Validator;
use App\Events\UserCreated;

class SignupController extends Controller
{
    private $callApiService;

    public function __construct(CallApiService $callApiService)
    {
        $this->callApiService = $callApiService;
    }

    public function index()
    {
        $passwdPolicy = setupPasswdPolicy('member');

        $smsCert = session('smsCert');

        if (empty($smsCert)) {
            notify()->error('잘못된 접근입니다', 'Error', 'bottomRight');
            return redirect()->route('member-signup-agree');
        }

        if ($smsCert['code'] !== 200) {
            notify()->error('인증실패', 'Error', 'bottomRight');
            return redirect()->route('member-signup-agree');
        }

        if (date('YmdHis') - $smsCert['date'] > 500) {
            session()->forget('smsCert');
            notify()->error('인증 시간이 만료되었습니다', 'Error', 'bottomRight');
            return redirect()->route('member-signup-agree');
        }

        return view('views.auth.member-signup', [
            'policyDesc' => $passwdPolicy['PolicyDesc'],
        ]);
    }

    public function store()
    {
        $passwdPolicy = setupPasswdPolicy('member');

        if ($this->callApiService->verifyApiError($passwdPolicy)) {
            notify()->error($passwdPolicy['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        $passwdRules = makePasswdRules($passwdPolicy);

        $validator = validator::make(request()->all(), [
            'email' => ['required', 'email'],
            'password' => $passwdRules,
        ]);

        if ($validator->fails()) {
            return redirect()->back()
                ->withErrors($validator)
                ->withInput();
        }

        $response = $this->callApiService->callApi([
            'url' => 'member-signup',
            'data' => [
                'Email' => request('email'),
                'Password' => request('password'),
                'SgroupCode' => request('sgroup_code'),
                'MobileNo' => formatPhone(request('mobile_no')),
            ]
        ]);

        if (isset($response['apiStatus'])) {
            notify()->error($response['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        // 가입확인 메일 보내는 이벤트
        event(new UserCreated([
            'email' => request('email'),
            'activate_code' => $response['ActivateCode']
        ]));

        notify()->success(_e('Action completed'), 'Success', 'bottomRight');
        return redirect()->route('member-go-email');
    }

    public function activateCodeResend()
    {
        $response = $this->callApiService->callApi([
            'url' => 'member-dupl-check',
            'data' => [
                'Email' => request('email')
            ]
        ]);

        if ($this->callApiService->verifyApiError($response)) {
            return redirect()->back();
        }

        event(new UserCreated([
            'email' => request('email'),
            'activate_code' => $response['ActivateCode']
        ]));

        notify()->success(_e('Action completed'), 'Success', 'bottomRight');
        return redirect()->route('member-go-email');
    }

    public function confirm()
    {
        $response = $this->callApiService->callApi([
            'url' => 'member-activate',
            'data' => [
                'ActivateCode' => request('code'),
            ],
        ]);

        if (isset($response['apiStatus'])) {
            return redirect()->route('member-activate-failed');
        } else {
            return redirect()->route('member-verify-ok');
        }
    }
}
