<?php

namespace Themes\eyerecord\pro\app\Http\Controllers\MyPage;

use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use Illuminate\Http\Request;
use Illuminate\Pagination\LengthAwarePaginator;

class CreditIoController extends Controller
{
    private $callApiService;

    public function __construct(CallApiService $callApiService)
    {
        $this->callApiService = $callApiService;
    }

    public function list()
    {
        $limit = (int)request('limit', 10);
        $page = (int)request('page', 1);

        $creditBdPage = $this->callApiService->callApi([
            'url' => 'list-type1-page',
            'data' => [
                'QueryVars' => [
                    'QueryName' => 'pro:shop/credit-bd',
                    'SimpleFilter' => "",
                    'IsntPagination' => false
                ],
                'ListType1Vars' => [
                    'OrderBy' => request('sort', 'mb.created_on desc')
                ],
                'PageVars' => [
                    'Limit' => $limit,
                    'Offset' => ($page - 1) * $limit
                ]
            ]
        ]);

        if ($this->callApiService->verifyApiError($creditBdPage)) {
            notify()->error($creditBdPage['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        dump($creditBdPage);

        $creditBdPage['Page'] = new LengthAwarePaginator($creditBdPage['Page'], $creditBdPage['PageVars']['QueryCnt'],
            $limit, $page, ['path' => request()->url()]);

        return view('views.my-page.credit-io-list', compact('creditBdPage'));
    }
}
