<?php

namespace Themes\eyerecord\pro\app\Http\Controllers\MyPage;

use App\Helpers\File;
use App\Helpers\ResponseConverter;
use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use Illuminate\Pagination\LengthAwarePaginator;

class MemberEditController extends Controller
{
    private $callApiService;

    public function __construct(CallApiService $callApiService)
    {
        $this->callApiService = $callApiService;
    }

    public function index()
    {
        $memberId = session('member')['MemberId'];
        $listType1Book = $this->callApiService->callApi([
            'url' => 'list-type1-book',
            'data' => [
                'Book' => [
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro/member-single',
                            'SimpleFilter' => "mx.id = $memberId",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                ]
            ]
        ]);

//        dd($listType1Book);
        if ($this->callApiService->verifyApiError($listType1Book)) {
            notify()->error($listType1Book['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        $member = $listType1Book['Book'][0]['Page'][0];
//        dump($member);

        return view('views.my-page.member-edit', compact('listType1Book', 'member'))
            ->with('codeTitle', [
                "sort('company-contact-bd')", "sort('company-destina-bd')", "paymethod('sorder')",
            ]);
    }

    public function store()
    {
        $response = $this->callApiService->callApi([
            'url' => 'member-act',
            'data' => [
                'Page' => [
                    [
                        'Id' => session('member')['MemberId'],
                        'NickName' => request('nick_name'),
                        'ProfileText' => request('profile_text'),
                        'ProfileWeb' => request('profile_web'),
                        'ProfileImg' => $this->uploadProfileImage() ?? request('old_profile_img'),
                    ]
                ]
            ],
        ]);

        if ($this->callApiService->verifyApiError($response)) {
            notify()->error($response['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        notify()->success(_e('Action completed'), 'Success', 'bottomRight');
        return redirect()->back();
    }

    public function uploadProfileImage()
    {
        if (request()->hasFile('profile_img')) {
            return File::uploadImg(request()->file('profile_img'));
        }

        return null;
    }
}
