<?php

namespace Themes\eyerecord\pro\app\Http\Controllers\MyPage;

use App\Helpers\ResponseConverter;
use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use Illuminate\Pagination\LengthAwarePaginator;

class OrderController extends Controller
{
    private $callApiService;

    public function __construct(CallApiService $callApiService)
    {
        $this->callApiService = $callApiService;
    }

    public function list()
    {
        $limit = (int)request('limit', 10);
        $page = (int)request('page', 1);

        $orderPage = $this->callApiService->callApi([
            'url' => 'simple-join-page',
            'data' => [
                'QueryVars' => [
                    'QueryName' => 'sorder-item-total',
                ],
                'PageVars' => [
                    'Desc' => 'sorder_no',
                    'Limit' => $limit,
                    'Offset' => ($page - 1) * $limit
                ]
            ],
        ]);


        if ($this->callApiService->verifyApiError($orderPage)) {
            notify()->error($orderPage['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        $total = number_format(collect($orderPage['Page'])->sum('SorderTotal'));
        $orderPage['Page'] = new LengthAwarePaginator($orderPage['Page'], $orderPage['PageVars']['QueryCnt'],
            $limit, $page, ['path' => request()->url()]);

        return view('views.my-page.order-list', compact('orderPage', 'total'))->with('codeTitle', [
            "status('sorder')",
        ]);
    }
}
