<?php

namespace Themes\eyerecord\pro\app\Http\Controllers\MyPage;

use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use Illuminate\Pagination\LengthAwarePaginator;
use Validator;

class TicketController extends Controller
{
    private $callApiService;

    public function __construct(CallApiService $callApiService)
    {
        $this->callApiService = $callApiService;
    }

    public function index()
    {
        return redirect()->to(request()->path().'/tab/list');
    }

    public function list()
    {
        $limit = (int)request('limit', 10);
        $page = (int)request('page', 1);
        $tab = request('tab', 'list');
        $memberId = session('member')['MemberId'];

        $ticketPage =  $this->callApiService->callApi([
            'url' => 'simple-join-page',
            'data' => [
                'QueryVars' => [
                    'QueryName' => 'post-member-user',
                    'SimpleFilter' => "member_id = $memberId and post_type_id = 2"
                ],
                'PageVars' => [
                    'Desc' => 'id',
                    'Limit' => $limit,
                    'Offset' => ($page - 1) * $limit
                ]
            ]
        ]);
//        dump($ticketPage);
        $ticketPage['Page'] = new LengthAwarePaginator($ticketPage['Page'], $ticketPage['PageVars']['QueryCnt'],
            $limit, $page, ['path' => request()->url()]);

        return view('views.my-page.ticket.ticket', compact('ticketPage', 'tab'))->with('codeTitle', [
            "status('ticket')",
        ]);
    }

    public function store()
    {
        $validator = Validator::make(request()->all(), [
            'post_title' => 'required',
            'post_contents' => 'required',
            'pc2' => 'nullable|email'
        ]);

        if ($validator->fails()) {
            notify()->error(_e('Action failed'), 'Error', 'bottomRight');
            return redirect()->back()
                ->withErrors($validator)
                ->withInput();
        }

        $response =  $this->callApiService->callApi([
            'url' => 'post-act',
            'data' => [
                'Page' => [
                    [
                        'Id' => 0,
                        'PostTitle' => request('post_title'),
                        'PostContents' => request('post_contents'),
                        'PostTypeId' => 2,
                        'Pc1' => request('pc1'),
                        'Pc2' => request('pc2'),
                        'Status' => '2',
                        'MemberId' => session('member')['MemberId'],
                    ]
                ]
            ],
        ]);

        if ($this->callApiService->verifyApiError($response)) {
            notify()->error($response['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        notify()->success(_e('Action completed'), 'Success', 'bottomRight');
        return redirect()->route('my-page.ticket-list.index');
    }
}
