<?php

namespace Themes\eyerecord\pro\app\Http\Controllers\Service;

use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use App\Services\Shop\ShippingChargeService;
class CheckoutController extends Controller
{
    private $callApiService;
    private $shippingChargeService;

    public function __construct(CallApiService $callApiService, ShippingChargeService $shippingChargeService)
    {
        $this->callApiService = $callApiService;
        $this->shippingChargeService = $shippingChargeService;
    }

    public function index()
    {
        $memberId = session('member')['MemberId'];

        $listType1Book = $this->callApiService->callApi([
            'url' => 'list-type1-book',
            'data' => [
                'Book' => [
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/cart',
                            'SubSimpleFilter' => "image_type = 'thumb'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro/setup',
                            'SimpleFilter' => "setup_code='shipping-charge' and is_default='1'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro/setup',
                            'SimpleFilter' => "setup_code='remit-account'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro/member-single',
                            'SimpleFilter' => "mx.id = $memberId",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro/setup',
                            'SimpleFilter' => "setup_code='import-pg'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro/setup',
                            'SimpleFilter' => "setup_code='shop-pay-method'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                ]
            ]
        ]);

        if ($this->callApiService->verifyApiError($listType1Book)) {
            notify()->error($listType1Book['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        // 아임포트pg 셋업
        $importPgSetup = json_decode($listType1Book['Book'][4]['Page'][0]['C1'], true);

        $cartList = collect($listType1Book['Book'][0]['Page'] ?? []);
//        dd($cartList);

        // 아이템 이름 구하기
        $checkoutCharge['item_name'] = '';
        $cartCount = $cartList->count();
        if ($cartCount === 1) {
            $checkoutCharge['item_name'] = $cartList[0]['C4'];
        } else if ($cartCount > 1) {
            $checkoutCharge['item_name'] = $cartList[0]['C4'] . '외 ' . ($cartCount - 1) . '개';
        }

        // 배송비 구하기
        $checkoutCharge['sub_total'] = collect($cartList)->sum('C8');
        $checkoutCharge['charge_amt'] = $this->shippingChargeService->calc($listType1Book['Book'][1]['Page'][0], $checkoutCharge['sub_total']);
        $checkoutCharge['total'] = $checkoutCharge['sub_total'] + $checkoutCharge['charge_amt'];
        $checkoutCharge['half_total'] = $checkoutCharge['total'] / 2;

//        dd($listType1Book['Book'][3]['Page'][0]);
        $member = $listType1Book['Book'][3]['Page'][0];

        return view('views.service.checkout',
            compact('listType1Book', 'checkoutCharge', 'member', 'importPgSetup'))
            ->with('codeTitle', [
                "sort('company-contact-bd')", "sort('company-destina-bd')", "paymethod('sorder')", "situation('sorder')",
            ]);

//        return view('views.service.checkout', compact('cartItem', 'buyer', 'total'));
    }

    public function store()
    {
        $cart =  $this->callApiService->callApi([
            'url' => 'list-type1-page',
            'data' => [
                'QueryVars' => [
                    'QueryName' => 'pro:shop/cart',
                    'SubSimpleFilter' => "image_type = 'thumb'",
                    'IsntPagination' => true,
                ],
                'PageVars' => [
                    'Limit' => 100000
                ]
            ],
        ]);

        if ($this->callApiService->verifyApiError($cart) || empty($cart['Page'])) {
            notify()->error($cart['body'] ?? '쇼핑카트가 비어있습니다', 'Error', 'bottomRight');
            return redirect()->route('checkout-failed');
        }

        $bdPage = collect($cart['Page'])->map(function ($cart) {
            return [
                'Id' => 0,
                'CartId' => $cart['Id'],
                'ItemId' => (int)$cart['C1'],
                'SorderPrc' => $cart['C6'],
                'SorderQty' => $cart['C7'],
                'SorderSum' => $cart['C8'],
                'SorderSupply' => '0',
                'SorderVat' => '0',
                'DiscountRate' => '0',
                'CurrPurchPrc' => '0',
                'CurrSalesPrc' => '0',
            ];
        })->toArray();

//        dd($bdPage);

        $status = request('status', '0');
        $situation = request('situation', '');

        $sorderBact = $this->callApiService->callApi([
            'url' => 'sorder-bact',
            'data' => [
                // 무통장 입금을 포함한 주문 성공
                'OkSuccess' => (bool)request('ok_success', false),
                // 무통장 입금을 제외한 결제 성공
                'OkPaid' => (bool)request('ok_paid', false),
                'HdPage' => [
                    [
                        'Id' => 0,
                        'BuyerId' => session('member')['MemberBuyerId'],
//                        'SgroupId' => session('member')['SgroupId'],
//                        'BranchId' => session('member')['BranchId'],
//                        'StorageId' => session('member')['StorageId'],
                        'DealTypeId' => 5,
                        'Status' => $status,
                        'Situation' => $situation,
                        'IsPro' => '1',
                        'CashAmt' => request('cash_amt', '0'),
                        'CcardAmt' => request('ccard_amt', '0'),

                        'Remarks' => request('remarks', ''),
                        'ShipContact' => request('ship_contact', ''),
                        'ShipMobile' => request('ship_mobile', ''),
                        'ShipFee' => request('ship_fee', ''),
                        'ShipZipCode' => request('ship_zip_code', ''),
                        'ShipAddr1' => request('ship_addr1', ''),
                        'ShipAddr2' => request('ship_addr2', ''),
                        'Paymethod' => request('paymethod'),
                        'RemitName' => request('remit_name', ''),
                        'RemitAccount' => request('remit_account', ''),
                    ]
                ],
                'BdPage' => $bdPage
            ]
        ]);

        switch ($status) {
            case 'F':
                notify()->error(request('situation_title', 'Error'), 'Error', 'bottomRight');
                return redirect()->route('checkout-failed');
            default;
                break;
        }

        if ($this->callApiService->verifyApiError($sorderBact)) {
            notify()->error($sorderBact['body'], 'Error', 'bottomRight');
            return redirect()->route('checkout-failed');
        }

        notify()->success(_e('Action completed'), 'Success', 'bottomRight');
        return redirect()->route('checkout-ok')->with(['sorder_id' => $sorderBact['HdPage'][0]['Id']]);
    }

    public function getBdParameter($sorderId, $cart)
    {
        return [
            'Id' => 0,
            'SorderId' => (int)$sorderId,
            'ItemId' => (int)$cart['ItemId'],
            'SorderQty' => $cart['CartQty'],
            'SorderPrc' => $cart['CartPrice'],
            'SorderSum' => $cart['CartAmt'],
            'SorderSupply' => '0',
            'SorderVat' => '0',
            'DiscountRate' => '0',
            'CurrPurchPrc' => '0',
            'CurrSalesPrc' => '0',
        ];
    }
}
