<?php

namespace Themes\eyerecord\pro\app\Http\Controllers\Service;

use App\Helpers\ResponseConverter;
use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use Illuminate\Pagination\LengthAwarePaginator;

class CreditItemController extends Controller
{
    private $callApiService;

    public function __construct(CallApiService $callApiService)
    {
        $this->callApiService = $callApiService;
    }

    public function index($igroupCode)
    {
        $limit = (int)request('limit', 7);
        $page = (int)request('page', 1);
        $search = request('search', '');

        $igroupPick = $this->callApiService->callApi([
            'url' => 'igroup-pick',
            'data' => [
                'Page' => [
                    ['IgroupCode' => $igroupCode ]
                ]
            ],
        ]);

        if ($this->callApiService->verifyApiError($igroupPick)) {
            notify()->error($igroupPick['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        $igroup = $igroupPick['Page'][0];

        $listType1Book = $this->callApiService->callApi([
            'url' => 'list-type1-book',
            'data' => [
                'Book' => [
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-gallery',
                            'SimpleFilter' => "igroup_code='$igroupCode' and mx.item_name LIKE '%$search%'",
                            'SubSimpleFilter' => "image_type = 'middle'",
                            'IsntPagination' => false,
                        ],
                        'ListType1Vars' => [
                            'OrderBy' => request('sort', 'mx.created_on desc')
                        ],
                        'PageVars' => [
                            'Limit' => $limit,
                            'Offset' => ($page - 1) * $limit
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/wish',
                            'SubSimpleFilter' => "image_type = 'thumb'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                ]
            ]
        ]);

        if ($this->callApiService->verifyApiError($listType1Book)) {
            notify()->error($listType1Book['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        $itemGallery['Page'] = ResponseConverter::joinFor($listType1Book['Book'][0]['Page'], $listType1Book['Book'][1]['Page'], 'C1');
//        dd($igroup);
        $itemGallery['Page'] = new LengthAwarePaginator($itemGallery['Page'], $listType1Book['Book'][0]['PageVars']['QueryCnt'],
            $limit, $page, ['path' => request()->url()]);

        return view('views.service.credit-item-list', compact('listType1Book', 'itemGallery', 'igroup'));
    }

    public function show($id)
    {
        $listType1Book = $this->callApiService->callApi([
            'url' => 'list-type1-book',
            'data' => [
                'Book' => [
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-details',
                            'SimpleFilter' => "mx.id = $id",
                            'SubSimpleFilter' => "image_type = 'middle'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 1
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-thm-media',
                            'SimpleFilter' => "mx.id = $id",
                            'SubSimpleFilter' => "image_type = 'middle'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 1
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/related-item-gallery',
                            'SimpleFilter' => '',
                            'SubSimpleFilter' => "image_type = 'big'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-details-prenext',
                            'SimpleFilter' => "mx.id = (select max(id) from dbr_item where id < ${id})",
                            'SubSimpleFilter' => "image_type = 'thumb'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 1
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/item-details-prenext',
                            'SimpleFilter' => "mx.id = (select min(id) from dbr_item where id > ${id})",
                            'SubSimpleFilter' => "image_type = 'thumb'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 1
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'pro:shop/wish',
                            'SubSimpleFilter' => "image_type = 'thumb'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                    [
                        'QueryVars' => [
                            'QueryName' => 'post/blog-single-center-std',
                            'SimpleFilter' => "mx.post_type_id = 15 and mx.status = '0'",
                            'IsntPagination' => true,
                        ],
                        'PageVars' => [
                            'Limit' => 100000
                        ]
                    ],
                ]
            ]
        ]);

        if ($this->callApiService->verifyApiError($listType1Book) || empty($listType1Book['Book'][0]['Page'])) {
            notify()->error($listType1Book['body'] ?? 'Api Error', 'Error', 'bottomRight');
            return redirect()->back();
        }

        $relatedItemGallery = ResponseConverter::joinFor($listType1Book['Book'][2]['Page'], $listType1Book['Book'][5]['Page'], 'C1');

//        dump($listType1Book);
        return view('views.service.credit-item-detail', compact('listType1Book', 'relatedItemGallery'));
    }
}
