<?php

namespace Themes\eyerecord\pro\app\Http\Controllers\Service;

use App\Http\Controllers\Controller;
use App\Services\CallApiService;
use Illuminate\Pagination\LengthAwarePaginator;

class PricingTableController extends Controller
{
    private $callApiService;

    public function __construct(CallApiService $callApiService)
    {
        $this->callApiService = $callApiService;
    }

    public function index()
    {
        $itemPage = $this->callApiService->callApi([
            'url' => 'item-page',
            'data' => [
                'PageVars' => [
                    'Query' => "expose_type='0' and is_credit_product='1'",
                    'Asc' => 'created_on',
                    'Limit' => 999,
                ]
            ],
        ]);

        return view('views.service.pricing', compact('itemPage'));
    }

    public function store()
    {
        if (empty(request('item_id'))) {
            notify()->error('상품을 선택해주세요', 'Error', 'bottomRight');
            return redirect()->back();
        }

        $item = $this->callApiService->callApi([
            'url' => 'item-pick',
            'data' => [
                'Page' => [
                    ['Id' => (int)request('item_id') ]
                ]
            ],
        ])['Page'][0];

        $cartPick = $this->callApiService->callApi([
            'url' => 'cart-pick',
            'data' => [
                'Page' => [
                    ['ItemId' => (int)request('item_id') ]
                ]
            ],
        ]);

        if ($this->callApiService->verifyApiError($cartPick)) {
            $id = 0;
            $cartQty = 1;
            $cartAmt = $item['SalesPrc'];
        } else {
            $cart = $cartPick['Page'][0];
            $id = $cart['Id'];
            $cartQty = (int)$cart['CartQty'] + 1;
            $cartAmt = $item['SalesPrc'] * $cartQty;
        }

        $response = $this->callApiService->callApi([
            'url' => 'cart-act',
            'data' => [
                'Page' => [
                    [
                        'Id' => $id,
                        'ItemId' => $item['Id'],
                        'CartQty' => (string)$cartQty,
                        'CartPrc' => (string)$item['SalesPrc'],
//                        'CartPrice' => (string)$item['SalesPrc'],
                        'CartAmt' => (string)$cartAmt,
                    ]
                ]
            ],
        ]);

        if ($this->callApiService->verifyApiError($response)) {
            notify()->error($response['body'], 'Error', 'bottomRight');
            return redirect()->back();
        }

        notify()->success(_e('Action completed'), 'Success', 'bottomRight');
        return redirect()->to(setupMemberPagemove()['AfterAddCartUri']);
    }

}
